- Fix bug #20: ``xoutil.future.calendar`` may fail at import time.

- Add ``xoutil.params.pop_keyword_values``.

- Add ``xoutil.future.collections.codedict``.  Deprecate module
  ``xoutil.formatter``.
